import {
  select,
  json,
  pie,
  arc,
  scaleOrdinal,
  format
} from 'd3';

const svg = select("svg");
const width = +svg.attr('width');
const height = +svg.attr('height');
const xAxisTickFormat = number =>
  	format('.4~g')(number);

// Factory para crear trozos
const render = data => {
  const pieData = pie().sort(null).value(d=>d.value)(data);
  
  const colors = scaleOrdinal()
  	.domain(data)
  	.range([
      "#018670",
      "#9b1e5b",
      "#8dc63f",
      "#f58026",
      "#4b4b4b",
      "#9acbc2",
      "#00b5cc",
      "#014140",
      "#d9d5d5"
    ]);
  
	const segments = arc()
  	.innerRadius(0)
  	.outerRadius(175)
  	.padAngle(0)
  	.padRadius(0);
  
  const sections = svg.append("g")
  	.attr("transform", `translate(250,250)`)
  	.selectAll("path").data(pieData);
  sections.enter().append("path").attr("d", segments)
  	.attr("fill", d => colors(d.data.value));
  
  // const content = select("g").selectAll("text").data(pieData);
  // content.enter().append("text").each(function(d,i){
  //   const center = segments.centroid(d);
  //   select(this)
  //   	.attr("x",center[0])
  //   	.attr("y",center[1])
  //   	.text( xAxisTickFormat(d.data.value));
  // });
  
  const legends = svg.append("g")
  	.attr("transform", "translate(500,100)")
    .selectAll(".legends").data(pieData);
  const legend = legends.enter().append("g").classed(".legends",true)
  	.attr("transform", (d,i)=>{
      return `translate(0,${(i+1)*30})`;
    });
  legend.append("rect").attr("width",20).attr("height",20)
  	.attr("fill", d => colors(d.data.value));
  legend.append("text")
  	.attr("x", 25)
  	.attr("y", 15)
  	.attr("class","legend_text")
  	.text(d => d.data.label);
  legend.append("text")
  	.attr("x", 250)
  	.attr("y", 15)
  	.attr("class","legend_value")
  	.text(d=>xAxisTickFormat(d.data.value)+"%");
}

json( 'data.json' ).then(data => {
  // Transformar strings a numeros
  data.forEach(d=>{
    d.value = +d.value;
  });
  render(data);
})